/* This is ftdi245io.h the definitions for ftdi245io						*
 * Based on libftdi, at http://www.intra2net.com/de/produkte/opensource/ftdi/			*
 * Copright by Richard Neill <fdti245io at REMOVE.ME.richardneill.org> 2004-2011. 		*
 * This is Free Software, released under the GNU GPL v2+: http://gnu.org/copyleft/gpl.html	*/

/* Author */
#define	AUTHOR			"Richard Neill"
#define AUTHOR_EMAIL		"ftdi245io AT REMOVE.ME. richardneill DOT org"
#define LICENSE			"GNU GPL v2+"
#define VERSION			"2.0"

/* DEBUG */
#define DEBUG                   0	      	/* DEBUG is 1 to enable verbose diagnostics; 0 otherwise. */

/* USB definitions */
#define VENDOR  		0x0403		/* These are FTDI defaults, unless changed by using ftdi_eeprom */
#define PRODUCT 		0x6001

/* PORT DEFINITIONS. Get these from `sudo lsusb -v | grep iSerial` */
#define PORTA_SERIAL		"DPE00SBP"	/* serial number of the ftdi module which I use for Port A.*/

/* PORT A output mask. (This is hardcoded here, because it is *my* hardware, and the PCB layout is fixed.) */
#define PORTA_OUTPUT_MASK	0xF8		/* The output direction mask for PortA. 1s are outputs, 0s are inputs. Eg 0x01 sets all pins to inputs, except bit_0. */

/* Lockfile for portA */
#define PORTA_LOCKFILE		"/tmp/ftdi245io_"PORTA_SERIAL

/* Buffer sizes */
#define INFOSIZE		128		/* Max length of string for the device strings (manufacturer,description,serial). (Probably shorter than this, but we don't know!) */
#define FTDI_TX_BUFSIZE		384  		/* The hardware Tx buffer inside the FTDI chip is 384 bytes. MUST be <= BUFSIZE. This is only used when clearing the connected FIFO; normally the readers are separate forks, and a larger buffer may be used. */
/*#DONTdefine READ_CHUNK_SIZE 4096 */		/* Libftdi's read chunk size MUST be the same as BUFSIZE. Don't #define anything here; this is only left here as a comment, so you don't do it! */
						/* (This normally defaults to 4096. Note also that the FTDI chip has a hardware Tx buffer of only 384 bytes. */

#define BUFSIZE			2048		/* Buffer size for reading from the Port, and writing into the child's end of the pipe. This also controls the read chunk size for libftdi (must be >=64). */
						/* 4096 is a good default, BUT we probably don't want a single transfer to fill the pipe capacity. Since Linux-2.4 pipee capacity is only */
						/* 4096 bytes, this is optimally reduced to 2048. For 2.6, Experiment.  Ref. man(7) pipe. */

/* Timers (neither of these is exact) */
#define LATENCY_TIMER 		16		/* This is the timeout (in ms) when the FTDI will send an incomplete Tx buffer will be sent over the bus anyway. Default 16ms, must be in range 1-255. 16 is optimal.*/
#define TIMEOUT_TIMER		500		/* This is the timeout (in ms) for --portbd_in_timeout. Choose any value here; it will be rounded up to an integer multiple of LATENCY_TIMER */

/* Exit codes */
#define FTDI_EXIT_OK			0	/* Exit with success */
#define FTDI_ERROR_GENERIC		1	/* Generic failure */
#define FTDI_ERROR_WRONGARGS		2	/* Failure: wrong arguments (or wrong config) */
#define FTDI_ERROR_INITFAIL		3	/* Couldn't initialise the ftdi context. */
#define FTDI_ERROR_OPENFAIL		4	/* Couldn't find/open a device. */
#define FTDI_ERROR_WRITEFAIL		5	/* Writing to device failed. */
#define FTDI_ERROR_READFAIL		6	/* Reading from device failed. */
#define FTDI_ERROR_CLOSEFAIL		7	/* Couldn't close the device properly. */
#define FTDI_ERROR_RESETFAIL		8	/* Resetting device failed. */
#define FTDI_ERROR_PURGEFAIL		9	/* Purging device buffers failed. */
#define FTDI_ERROR_CONFIGFAIL		10	/* Configuring hardware settings failed. */


/* Debug macro */
#if DEBUG==1
	#define eprintf(...)   fprintf(stderr, __VA_ARGS__)
#else
	#define eprintf(...)
#endif
